==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/CoverageByDate.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYDURATIONDAYS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}THRESHHOLDDAYS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "startdate",
    "expirationdate",
    "warrantydurationdays",
    "threshholddays"
})
@XmlRootElement(name = "CoverageByDate")
public class CoverageByDate {

    @XmlElement(name = "STARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME startdate;
    @XmlElement(name = "EXPIRATIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME expirationdate;
    @XmlElement(name = "WARRANTYDURATIONDAYS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double warrantydurationdays;
    @XmlElement(name = "THRESHHOLDDAYS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY threshholddays;

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Obtient la valeur de la propriété expirationdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXPIRATIONDATE() {
        return expirationdate;
    }

    /**
     * Définit la valeur de la propriété expirationdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXPIRATIONDATE(DATETIME value) {
        this.expirationdate = value;
    }

    /**
     * Obtient la valeur de la propriété warrantydurationdays.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getWARRANTYDURATIONDAYS() {
        return warrantydurationdays;
    }

    /**
     * Définit la valeur de la propriété warrantydurationdays.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setWARRANTYDURATIONDAYS(Double value) {
        this.warrantydurationdays = value;
    }

    /**
     * Obtient la valeur de la propriété threshholddays.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTHRESHHOLDDAYS() {
        return threshholddays;
    }

    /**
     * Définit la valeur de la propriété threshholddays.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTHRESHHOLDDAYS(QUANTITY value) {
        this.threshholddays = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/CoverageByDate.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYDURATIONDAYS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}THRESHHOLDDAYS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "startdate",
    "expirationdate",
    "warrantydurationdays",
    "threshholddays"
})
@XmlRootElement(name = "CoverageByDate")
public class CoverageByDate {

    @XmlElement(name = "STARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME startdate;
    @XmlElement(name = "EXPIRATIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME expirationdate;
    @XmlElement(name = "WARRANTYDURATIONDAYS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double warrantydurationdays;
    @XmlElement(name = "THRESHHOLDDAYS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY threshholddays;

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Gets the value of the expirationdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXPIRATIONDATE() {
        return expirationdate;
    }

    /**
     * Sets the value of the expirationdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXPIRATIONDATE(DATETIME value) {
        this.expirationdate = value;
    }

    /**
     * Gets the value of the warrantydurationdays property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getWARRANTYDURATIONDAYS() {
        return warrantydurationdays;
    }

    /**
     * Sets the value of the warrantydurationdays property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setWARRANTYDURATIONDAYS(Double value) {
        this.warrantydurationdays = value;
    }

    /**
     * Gets the value of the threshholddays property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTHRESHHOLDDAYS() {
        return threshholddays;
    }

    /**
     * Sets the value of the threshholddays property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTHRESHHOLDDAYS(QUANTITY value) {
        this.threshholddays = value;
    }

}
